@@ -34,7 +34,6 @@ def parse_parameters(fname):
     parameters['systemic'] = [None, 'none']
     parameters['clear_mask'] = False
     parameters['velspan'] = 500.
-    parameters['snr'] = None
     parameters['output_pars'] = list()
     parameters['options'] = list()
     parameters['fit_options'] = fit_options_defaults
@@ -87,11 +86,27 @@ def parse_parameters(fname):
             else:
                 nsub = 1
 
+            if 'ext=' in line:
+                # find value of nsub:
+                for item in pars[2:]:
+                    if 'ext=' in item:
+                        try:
+                            ext = int(item.split('=')[1])
+                        except ValueError:
+                            ext = item.split('=')[1]
+            else:
+                ext = None
+
+            if 'no-mask' in line:
+                use_mask = False
+            else:
+                use_mask = True
+
             # search for 'norm' and 'air':
-            norm = line.find('norm') > 0
-            air = line.find('air') > 0
+            norm = line.lower().find('norm') > 0
+            air = line.lower().find('air') > 0
             airORvac = 'air' if air else 'vac'
-            data.append([filename, resolution, norm, airORvac, nsub])
+            data.append([filename, resolution, norm, airORvac, nsub, ext, use_mask])
 
         elif 'lines' in line and 'save' not in line and 'fine' not in line and 'check' not in line:
             velspan = None
@@ -449,15 +464,8 @@ def parse_parameters(fname):
             parameters['show_total'] = True
 
         elif 'signal-to-noise' in line and 'name' not in line and 'save' not in line:
-            comment_begin = line.find('#')
-            line = line[:comment_begin].strip()
-            if '=' in line:
-                snr = line.split('=')[1]
-            elif ' ' in line:
-                snr = line.split()[1]
-            elif ':' in line:
-                snr = line.split(':')[1]
-            parameters['snr'] = float(snr)
+            print(" [WARNING] - The signal-to-noise command is deprecated.")
+            print("             The user must provide an error array.")
 
         elif (('velspan' in line) and ('lines' not in line) and ('molecules' not in line) and ('save' not in line)):
             # strip comments:
